==> aroundme_0_6_2.zip: aroundme_0_6_2/aroundme/language/1/barnraiser_01/grp_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------

require_once($languagePath . 'grp_common.lang.php');


//HEADER
$lang['hdr_schedule'] = 						"schedule items";
$lang['hdr_library'] = 							"wiki";
$lang['hdr_recommended_s'] = 					"recommended discussions";
$lang['hdr_recommended_b'] = 					"recommended blogs";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_group_summary'] = 					"introducing this group";
$lang['hdr_tag'] = 								"tags";
$lang['hdr_comments'] = 						"latest comments";
$lang['hdr_membership'] = 						"membership";
$lang['hdr_events'] = 							"events";
$lang['hdr_tasks'] = 							"tasks";


// OPTIONS
$lang['txt_option_blog'] = 							"group blog";
$lang['txt_option_forum'] = 						"group discussions";
$lang['txt_option_poll'] = 							"group polls";
$lang['txt_option_file'] = 							"group files";
$lang['txt_option_library'] = 						"group wiki";
$lang['txt_option_schedule'] = 						"group schedule";
$lang['txt_option_channel'] = 						"group channels";
$lang['txt_option_directory'] = 					"group directory";
$lang['txt_option_newsletter'] = 					"group newsletter";




//A HREF TAGS (links)
$lang['href_join'] = 							"join this group!";


// ERROR
$lang['err_no_comments'] = 						"Sorry, there are no comments available.";

// SUB
$lang['sub_update_tag'] = 						"update my tags";


//BODY TEXT
$lang['txt_hidden'] = 							"hidden";
$lang['txt_tag_intro'] = 						"This group has been tagged with";
$lang['txt_tag_network'] = 						"My network have tagged this group with";
$lang['txt_tag_group'] = 						"This group has tagged this group with";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_from'] =								"From";
$lang['txt_hometown'] = 						"home town";
$lang['txt_joined'] = 							"joined";
$lang['txt_allocation'] = 						"allocation";

?>

==> aroundme_0_6_9.zip: aroundme_0_6_9/aroundme/language/1/barnraiser_01/grp_view.lang.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
//
// Copyright (C) 2003 - 2006 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
//
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
//
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------


//HEADER
$lang['hdr_schedule'] = 						"schedule items";
$lang['hdr_library'] = 							"wiki";
$lang['hdr_recommended_s'] = 					"recommended discussions";
$lang['hdr_recommended_b'] = 					"recommended blogs";
$lang['hdr_statistics'] = 						"statistics";
$lang['hdr_polls'] = 							"polls";
$lang['hdr_group_summary'] = 					"introducing this group";
$lang['hdr_tag'] = 								"tags";
$lang['hdr_comments'] = 						"latest comments";
$lang['hdr_membership'] = 						"membership";
$lang['hdr_events'] = 							"events";
$lang['hdr_tasks'] = 							"tasks";
$lang['hdr_quizzes'] = 							"quizzes";


//A HREF TAGS (links)
$lang['href_join'] = 							"join this group!";


// ERROR
$lang['err_no_comments'] = 						"Sorry, there are no comments available.";

// SUB
$lang['sub_update_tag'] = 						"update my tags";


//BODY TEXT
$lang['txt_hidden'] = 							"hidden";
$lang['txt_tag_intro'] = 						"This group has been tagged with";
$lang['txt_tag_network'] = 						"My network have tagged this group with";
$lang['txt_tag_group'] = 						"This group has tagged this group with";
$lang['txt_comment_datetime'] =					"Comment date and time";
$lang['txt_from'] =								"From";
$lang['txt_hometown'] = 						"home town";
$lang['txt_joined'] = 							"joined";
$lang['txt_allocation'] = 						"allocation";

?>
